@@ -122,10 +122,10 @@ class KeyframeCurve(FigureCanvas, Loggable):
 
         self._ax.tick_params(axis='both',
                              which='both',
-                             bottom='off',
-                             top='off',
-                             right='off',
-                             left='off')
+                             bottom=False,
+                             top=False,
+                             right=False,
+                             left=False)
 
         # This seems to also be necessary for transparency ..
         figure.patch.set_visible(False)
@@ -572,14 +572,15 @@ class TimelineElement(Gtk.Layout, Zoomable, Loggable):
 
     # Callbacks
     def __selectedChangedCb(self, unused_selected, selected):
-        if not self.keyframe_curve and self.__controlledProperty:
+        if not self.keyframe_curve and self.__controlledProperty and \
+                selected and len(self.timeline.selection) == 1:
             self.__create_keyframe_curve()
 
         if self.keyframe_curve:
             self.__update_keyframe_curve_visibility()
 
         if self.__previewer:
-            self.__previewer.setSelected(selected)
+            self.__previewer.set_selected(selected)
 
     def __update_keyframe_curve_visibility(self):
         """Updates the keyframes widget visibility by adding or removing it."""
@@ -705,7 +706,7 @@ class VideoSource(TimelineElement):
         video_source = self._ges_elem
         sinfo = video_source.get_asset().get_stream_info()
 
-        asset_width = sinfo.get_width()
+        asset_width = sinfo.get_square_width()
         asset_height = sinfo.get_height()
         parent = video_source.get_parent()
         if parent and not self.__videoflip:
@@ -726,7 +727,7 @@ class VideoSource(TimelineElement):
             assert res
             if "clockwise" in method.value_nick and self.__videoflip.props.active:
                 asset_width = sinfo.get_height()
-                asset_height = sinfo.get_width()
+                asset_height = sinfo.get_square_width()
 
         # Find the biggest size of the video inside the
         # final view (project size) keeping the aspect ratio
@@ -1069,13 +1070,12 @@ class Clip(Gtk.EventBox, Zoomable, Loggable):
                 self.timeline.current_group.remove(
                     self.ges_clip.get_toplevel_parent())
                 mode = UNSELECT
-        elif not self.get_state_flags() & Gtk.StateFlags.SELECTED:
-            self.timeline.resetSelectionGroup()
-            self.timeline.current_group.add(
-                self.ges_clip.get_toplevel_parent())
-            self.app.gui.switchContextTab(self.ges_clip)
+            clicked_layer, click_pos = self.timeline.get_clicked_layer_and_pos(event)
+            self.timeline.set_selection_meta_info(clicked_layer, click_pos, mode)
         else:
             self.timeline.resetSelectionGroup()
+            self.timeline.current_group.add(self.ges_clip.get_toplevel_parent())
+            self.app.gui.switchContextTab(self.ges_clip)
 
         parent = self.ges_clip.get_parent()
         if parent == self.timeline.current_group or parent is None:
